Error

Enum Error 

pub enum Error {
    BandsEmpty,
    BandLimitsWrongOrder,
    BandLimitsOutOfBounds,
    BandsOverlap,
    ProxyDerivativeZero,
    EigenvaluesError(String),
    InvalidResponse(InvalidResponse),
    NotEnoughExtrema,
}
pm_remez error.

This enum represents all the errors that can be produced by pm_remez.

Variants



BandsEmpty

The list of bands is empty.



BandLimitsWrongOrder

The begin of the band is greater than the end of the band.



BandLimitsOutOfBounds

The band limits are out of bounds.



BandsOverlap

The bands overlap.



ProxyDerivativeZero

The derivative of the Chebyshev proxy polynomial is zero.

This error can happen due to numerical errors, and it prevents the Remez exchange algorithm from continuing.



EigenvaluesError(String)

An error happened during the computation of eigenvalues.

Eigenvalues are computed to find the roots of the derivative of the Chebyshev proxy. This error is typically produced by LAPACK, and it can happen due to numerical errors. It prevents the Remez exchange algorithm from continuing.



InvalidResponse(InvalidResponse)

The desired response that was specified is invalid for this type of FIR filter.



NotEnoughExtrema

Not enough alternating extrema were found for Remez exchange.

This error is typically caused by numerical errors.